==> vue-cedarmaps-0.1.8.tgz: package/README.md <==
<a  href="https://www.cedarmaps.com">

<img  src="http://api.cedarmaps.com/docs/img/cedarmaps-api.png"  width="500"/>

</a>

# CedarMaps SDK for React

## What is CedarMaps?

CedarMaps is the location data platform for mobile and web applications. We provide [building blocks](https://www.cedarmaps.com) to add location features like maps, search, and navigation into any experience you create. Use our simple and powerful APIs & SDKs and our open source libraries for interactivity and control.

## Sign up for CedarMaps

Not a CedarMaps user yet? [Sign up for an account here](https://www.cedarmaps.com/#demo). Once you’re signed in, all you need to start building is a CedarMaps access token.

---

This guide will take you through the process of integrating CedarMaps into your React application.

This package is a wrapper over [react-mapbox-gl](https://github.com/alex3165/react-mapbox-gl) library.

## Table of Contents

- [Installation](#installation)

- [Rendering Component](#rendering-component)

- [Adding Markers](#adding-markers)

- [Example](#example)

## Installation

**Npm**

```
npm install vue-cedarmaps --save
```

**Yarn**

```
yarn add vue-cedarmaps
```

## Rendering Component

```js
import CedarMaps from "vue-cedarmaps";
```

```js

<template>
  <div id="app">
    <Cedarmaps
      style="height: 600px"
      :center="['51.652878', '32.60999']"
      token="d1fe86dd94f013fd1e0897adf8d64d8f329cbaac"
      :zoom="12"
    >
      <MglNavigationControl position="top-right" />
      <MglMarker :coordinates="marker" color="blue" />
    </Cedarmaps>
  </div>
</template>

<script>
import {
  Cedarmaps,
  MglMarker,
  MglNavigationControl
} from "vue-cedarmaps";

export default {
  name: "app",
  components: {
    Cedarmaps,
    MglNavigationControl,
    MglMarker
  },
  data() {
    return {
      marker: [51.652878, 32.60999]
    };
  }
};
</script>

<style>
* {
  padding: 0;
  margin: 0;
}
</style>

```

You can read more about `Vue Mapbox` in [Vue Mapbox Documentation](https://soal.github.io/vue-mapbox/)

## Example

You can consult [this example](https://codesandbox.io/s/epic-grothendieck-kfd5x?fontsize=14&hidenavigation=1&theme=dark) for getting acquainted with our package.

==> vue-cedarmaps-0.2.1.tgz: package/README.md <==
<a  href="https://www.cedarmaps.com">

<img  src="http://api.cedarmaps.com/docs/img/cedarmaps-api.png"  width="500"/>

</a>

# CedarMaps SDK for Vue

## What is CedarMaps?

CedarMaps is the location data platform for mobile and web applications. We provide [building blocks](https://www.cedarmaps.com) to add location features like maps, search, and navigation into any experience you create. Use our simple and powerful APIs & SDKs and our open source libraries for interactivity and control.

## Sign up for CedarMaps

Not a CedarMaps user yet? [Sign up for an account here](https://www.cedarmaps.com/#demo). Once you’re signed in, all you need to start building is a CedarMaps access token.

---

This guide will take you through the process of integrating CedarMaps into your Vue application.

This package is a wrapper over [Vue Mapbox](https://soal.github.io/vue-mapbox/) library.

## Table of Contents

- [Installation](#installation)

- [Rendering Component](#rendering-component)

- [Adding Markers](#adding-markers)

- [Example](#example)

## Installation

**Npm**

```
npm install vue-cedarmaps --save
```

**Yarn**

```
yarn add vue-cedarmaps
```

## Rendering Component

```js
import CedarMaps from "vue-cedarmaps";
```

```js

<template>
  <div id="app">
    <Cedarmaps
      style="height: 600px"
      :center="['51.652878', '32.60999']"
      token="token"
      :zoom="12"
    >
      <MglNavigationControl position="top-right" />
      <MglMarker :coordinates="marker" color="blue" />
    </Cedarmaps>
  </div>
</template>

<script>
import {
  Cedarmaps,
  MglMarker,
  MglNavigationControl
} from "vue-cedarmaps";

export default {
  name: "app",
  components: {
    Cedarmaps,
    MglNavigationControl,
    MglMarker
  },
  data() {
    return {
      marker: [51.652878, 32.60999]
    };
  }
};
</script>

<style>
* {
  padding: 0;
  margin: 0;
}
</style>

```

You can read more about `Vue Mapbox` in [Vue Mapbox Documentation](https://soal.github.io/vue-mapbox/)

## Example

You can consult [this example](https://codesandbox.io/s/epic-grothendieck-kfd5x?fontsize=14&hidenavigation=1&theme=dark) for getting acquainted with our package.
